@@ -6,7 +6,13 @@ require 'concurrent/channel'
 require 'concurrent/exchanger'
 require 'concurrent/lazy_register'
 
-require 'concurrent/edge/future'
-require 'concurrent/edge/lock_free_stack'
 require 'concurrent/edge/atomic_markable_reference'
 require 'concurrent/edge/lock_free_linked_set'
+require 'concurrent/edge/lock_free_queue'
+require 'concurrent/edge/lock_free_stack'
+
+require 'concurrent/edge/promises'
+require 'concurrent/edge/cancellation'
+require 'concurrent/edge/throttle'
+
+require 'concurrent/edge/processing_actor'
