@@ -9,8 +9,6 @@ unless Concurrent.on_jruby?
   # long as `ReentrantReadWriteLock` is not changed (with respect to
   # `ThreadLocalVar`) we can safely assume proper functionality on JRuby.
 
-  require 'concurrent/atomic/reentrant_read_write_lock'
-  require 'concurrent/atomic/count_down_latch'
   require 'timeout'
 
   module Concurrent
@@ -262,7 +260,7 @@ unless Concurrent.on_jruby?
           end
         end
 
-        it "wakes up waiting readers when the write lock is released" do
+        it "wakes up waiting readers when the write lock is released", buggy: true do
           latch1,latch2 = CountDownLatch.new,CountDownLatch.new
           good = AtomicFixnum.new(0)
           threads = [
@@ -273,6 +271,7 @@ unless Concurrent.on_jruby?
           ]
           wait_up_to(0.2) { threads[3].status == 'sleep' }
           # The last 3 threads should be waiting to acquire read locks now...
+          # TODO (pitr-ch 15-Oct-2016): https://travis-ci.org/ruby-concurrency/concurrent-ruby/jobs/166777543
           (1..3).each { |n| expect(threads[n].status).to eql "sleep" }
           (1..3).each { |n| expect(threads[n]).not_to hold(lock).for_read }
           # Throw latch2 and the writer will wake up and release its write lock...
