@@ -2,7 +2,7 @@ require_relative 'buffered_shared'
 
 module Concurrent::Channel::Buffer
 
-  describe Buffered do
+  describe Buffered, edge: true do
 
     let(:capacity) { 10 }
     subject { described_class.new(capacity) }
